.. pcassie documentation master file, created by
   sphinx-quickstart on Tue Jul 29 01:30:32 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

pcassie documentation
=====================

Add your content using ``reStructuredText`` syntax. See the
`reStructuredText <https://www.sphinx-doc.org/en/master/usage/restructuredtext/index.html>`_
documentation for details.


.. toctree::
   :maxdepth: 2
   :numbered:
   :caption: Contents:

   Installation <install.rst> 
   intro.rst
   calibration.rst
   ccf.rst
   ccf_tests.rst
   pca_subtraction.rst
   pipeline.rst
   plot_functions.rst
   utility_functions.rst


